==> jc-1.4.0.tar.gz: javax/swing/JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon.h <==
// public class javax.swing.JInternalFrame$JDesktopIcon$AccessibleJDesktopIcon

// class file dependencies
// @dep_class 61b24c22f38bff85 java_awt_Component__24AccessibleAWTComponent
// @dep_class 6d5f0a9d86bc5fc4 java_awt_Container__24AccessibleAWTContainer
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class d2c97b9b1866e7b0 javax_accessibility_AccessibleContext
// @dep_class 32f620e3c8c75689 javax_swing_JComponent__24AccessibleJComponent
// @dep_class 776ba135c00ebbcb javax_swing_JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon

// header file dependencies
// @dep_header javax_swing_JComponent__24AccessibleJComponent

#include "javax/swing/JComponent__24AccessibleJComponent.h"

#ifndef _JC_javax_swing_JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon_H_
#define _JC_javax_swing_JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Number$object;
struct _jc_javax_accessibility_AccessibleRole$object;
struct _jc_javax_accessibility_AccessibleValue$object;
struct _jc_javax_swing_JInternalFrame__24JDesktopIcon$object;

// Typedefs
typedef struct _jc_javax_swing_JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon$sub_refs	_jc_javax_swing_JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon$sub_refs;
typedef struct _jc_javax_swing_JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon$sub_nonrefs	_jc_javax_swing_JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon$sub_nonrefs;
typedef struct _jc_javax_swing_JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon$refs	_jc_javax_swing_JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon$refs;
typedef struct _jc_javax_swing_JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon$nonrefs	_jc_javax_swing_JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon$nonrefs;
typedef struct _jc_javax_swing_JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon$object	_jc_javax_swing_JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon$object;

typedef const struct _jc_javax_swing_JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon$vmethods	_jc_javax_swing_JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon$vmethods;
typedef const struct _jc_javax_swing_JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon$vtable	_jc_javax_swing_JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon$vtable;
typedef const struct _jc_javax_swing_JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon$vtype	_jc_javax_swing_JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon$vtype;

// Constructors
extern void _jc_javax_swing_JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon$method$_init$51548b3984ade626(_jc_env *, struct _jc_javax_swing_JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon$object *, struct _jc_javax_swing_JInternalFrame__24JDesktopIcon$object *);

// Virtual methods
extern struct _jc_javax_accessibility_AccessibleRole$object *_jc_javax_swing_JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon$method$getAccessibleRole$eaa05a502d0ede18(_jc_env *, struct _jc_javax_swing_JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon$object *);
extern struct _jc_object *_jc_javax_swing_JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon$method$getAccessibleValue$ba7fc7ffdb66e551(_jc_env *, struct _jc_javax_swing_JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon$object *);
extern struct _jc_java_lang_Number$object *_jc_javax_swing_JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon$method$getCurrentAccessibleValue$c2e330a40c3d2acc(_jc_env *, struct _jc_javax_swing_JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon$object *);
extern struct _jc_java_lang_Number$object *_jc_javax_swing_JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon$method$getMaximumAccessibleValue$ec00d2a63914585e(_jc_env *, struct _jc_javax_swing_JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon$object *);
extern struct _jc_java_lang_Number$object *_jc_javax_swing_JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon$method$getMinimumAccessibleValue$eeb09b9145034e84(_jc_env *, struct _jc_javax_swing_JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon$object *);
extern jboolean _jc_javax_swing_JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon$method$setCurrentAccessibleValue$0ceb1cadc12f10f4(_jc_env *, struct _jc_javax_swing_JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon$object *, struct _jc_java_lang_Number$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon$method_info$getAccessibleRole$eaa05a502d0ede18;
extern _jc_method _jc_javax_swing_JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon$method_info$getAccessibleValue$ba7fc7ffdb66e551;
extern _jc_method _jc_javax_swing_JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon$method_info$getCurrentAccessibleValue$c2e330a40c3d2acc;
extern _jc_method _jc_javax_swing_JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon$method_info$getMaximumAccessibleValue$ec00d2a63914585e;
extern _jc_method _jc_javax_swing_JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon$method_info$getMinimumAccessibleValue$eeb09b9145034e84;
extern _jc_method _jc_javax_swing_JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon$method_info$setCurrentAccessibleValue$0ceb1cadc12f10f4;

// Virtual methods structure
struct _jc_javax_swing_JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon$vmethods {
	struct _jc_javax_accessibility_AccessibleRole$object	*(*getAccessibleRole$eaa05a502d0ede18)(_jc_env *, struct _jc_javax_swing_JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon$object *);
	struct _jc_object	*(*getAccessibleValue$ba7fc7ffdb66e551)(_jc_env *, struct _jc_javax_swing_JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon$object *);
	struct _jc_java_lang_Number$object	*(*getCurrentAccessibleValue$c2e330a40c3d2acc)(_jc_env *, struct _jc_javax_swing_JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon$object *);
	struct _jc_java_lang_Number$object	*(*getMaximumAccessibleValue$ec00d2a63914585e)(_jc_env *, struct _jc_javax_swing_JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon$object *);
	struct _jc_java_lang_Number$object	*(*getMinimumAccessibleValue$eeb09b9145034e84)(_jc_env *, struct _jc_javax_swing_JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon$object *);
	jboolean	(*setCurrentAccessibleValue$0ceb1cadc12f10f4)(_jc_env *, struct _jc_javax_swing_JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon$object *, struct _jc_java_lang_Number$object *);
};

// Vtable
struct _jc_javax_swing_JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_accessibility_AccessibleContext$vmethods	javax_accessibility_AccessibleContext;
	_jc_java_awt_Component__24AccessibleAWTComponent$vmethods	java_awt_Component__24AccessibleAWTComponent;
	_jc_java_awt_Container__24AccessibleAWTContainer$vmethods	java_awt_Container__24AccessibleAWTContainer;
	_jc_javax_swing_JComponent__24AccessibleJComponent$vmethods	javax_swing_JComponent__24AccessibleJComponent;
	_jc_javax_swing_JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon$vmethods	javax_swing_JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon;
};

// Vtype
struct _jc_javax_swing_JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon$vtype {
	_jc_type			type;
	_jc_javax_swing_JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon$sub_refs {
	struct _jc_javax_swing_JInternalFrame__24JDesktopIcon$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon$refs {
    _jc_javax_swing_JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon$sub_refs	javax_swing_JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon;
    _jc_javax_swing_JComponent__24AccessibleJComponent$sub_refs	javax_swing_JComponent__24AccessibleJComponent;
    _jc_java_awt_Container__24AccessibleAWTContainer$sub_refs	java_awt_Container__24AccessibleAWTContainer;
    _jc_java_awt_Component__24AccessibleAWTComponent$sub_refs	java_awt_Component__24AccessibleAWTComponent;
    _jc_javax_accessibility_AccessibleContext$sub_refs	javax_accessibility_AccessibleContext;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_accessibility_AccessibleContext$sub_nonrefs	javax_accessibility_AccessibleContext;
    _jc_java_awt_Component__24AccessibleAWTComponent$sub_nonrefs	java_awt_Component__24AccessibleAWTComponent;
    _jc_java_awt_Container__24AccessibleAWTContainer$sub_nonrefs	java_awt_Container__24AccessibleAWTContainer;
    _jc_javax_swing_JComponent__24AccessibleJComponent$sub_nonrefs	javax_swing_JComponent__24AccessibleJComponent;
    _jc_javax_swing_JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon$sub_nonrefs	javax_swing_JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon;
};

// Object instance structure
struct _jc_javax_swing_JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon$object {
	_jc_javax_swing_JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon$vtype	*vtype;
	_jc_javax_swing_JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon$vtype _jc_javax_swing_JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon$class_object;

#endif	/* _JC_javax_swing_JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon_H_ */

==> jc-1.4.5.tar.gz: javax/swing/JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon.h <==
// public class javax.swing.JInternalFrame$JDesktopIcon$AccessibleJDesktopIcon

// class file dependencies
// @dep_class e1ad6f3c35669e42 java_awt_Component__24AccessibleAWTComponent
// @dep_class 6d5f0a9d86bc5fc4 java_awt_Container__24AccessibleAWTContainer
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class d2c97b9b1866e7b0 javax_accessibility_AccessibleContext
// @dep_class 32f620e3c8c75689 javax_swing_JComponent__24AccessibleJComponent
// @dep_class 776ba135c00ebbcb javax_swing_JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon

// header file dependencies
// @dep_header javax_swing_JComponent__24AccessibleJComponent

#include "javax/swing/JComponent__24AccessibleJComponent.h"

#ifndef _JC_javax_swing_JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon_H_
#define _JC_javax_swing_JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Number$object;
struct _jc_javax_accessibility_AccessibleRole$object;
struct _jc_javax_accessibility_AccessibleValue$object;
struct _jc_javax_swing_JInternalFrame__24JDesktopIcon$object;

// Typedefs
typedef struct _jc_javax_swing_JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon$sub_refs	_jc_javax_swing_JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon$sub_refs;
typedef struct _jc_javax_swing_JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon$sub_nonrefs	_jc_javax_swing_JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon$sub_nonrefs;
typedef struct _jc_javax_swing_JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon$refs	_jc_javax_swing_JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon$refs;
typedef struct _jc_javax_swing_JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon$nonrefs	_jc_javax_swing_JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon$nonrefs;
typedef struct _jc_javax_swing_JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon$object	_jc_javax_swing_JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon$object;

typedef const struct _jc_javax_swing_JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon$vmethods	_jc_javax_swing_JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon$vmethods;
typedef const struct _jc_javax_swing_JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon$vtable	_jc_javax_swing_JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon$vtable;
typedef const struct _jc_javax_swing_JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon$vtype	_jc_javax_swing_JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon$vtype;

// Constructors
extern void _jc_javax_swing_JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon$method$_init$51548b3984ade626(_jc_env *, struct _jc_javax_swing_JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon$object *, struct _jc_javax_swing_JInternalFrame__24JDesktopIcon$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_javax_accessibility_AccessibleRole$object *_jc_javax_swing_JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon$method$getAccessibleRole$eaa05a502d0ede18(_jc_env *, struct _jc_javax_swing_JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_javax_swing_JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon$method$getAccessibleValue$ba7fc7ffdb66e551(_jc_env *, struct _jc_javax_swing_JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Number$object *_jc_javax_swing_JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon$method$getCurrentAccessibleValue$c2e330a40c3d2acc(_jc_env *, struct _jc_javax_swing_JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Number$object *_jc_javax_swing_JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon$method$getMaximumAccessibleValue$ec00d2a63914585e(_jc_env *, struct _jc_javax_swing_JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Number$object *_jc_javax_swing_JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon$method$getMinimumAccessibleValue$eeb09b9145034e84(_jc_env *, struct _jc_javax_swing_JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon$object *) _JC_JCNI_ATTR;
extern jboolean _jc_javax_swing_JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon$method$setCurrentAccessibleValue$0ceb1cadc12f10f4(_jc_env *, struct _jc_javax_swing_JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon$object *, struct _jc_java_lang_Number$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon$method_info$getAccessibleRole$eaa05a502d0ede18;
extern _jc_method _jc_javax_swing_JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon$method_info$getAccessibleValue$ba7fc7ffdb66e551;
extern _jc_method _jc_javax_swing_JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon$method_info$getCurrentAccessibleValue$c2e330a40c3d2acc;
extern _jc_method _jc_javax_swing_JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon$method_info$getMaximumAccessibleValue$ec00d2a63914585e;
extern _jc_method _jc_javax_swing_JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon$method_info$getMinimumAccessibleValue$eeb09b9145034e84;
extern _jc_method _jc_javax_swing_JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon$method_info$setCurrentAccessibleValue$0ceb1cadc12f10f4;

// Virtual methods structure
struct _jc_javax_swing_JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon$vmethods {
	struct _jc_javax_accessibility_AccessibleRole$object	*(*getAccessibleRole$eaa05a502d0ede18)(_jc_env *, struct _jc_javax_swing_JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getAccessibleValue$ba7fc7ffdb66e551)(_jc_env *, struct _jc_javax_swing_JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Number$object	*(*getCurrentAccessibleValue$c2e330a40c3d2acc)(_jc_env *, struct _jc_javax_swing_JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Number$object	*(*getMaximumAccessibleValue$ec00d2a63914585e)(_jc_env *, struct _jc_javax_swing_JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Number$object	*(*getMinimumAccessibleValue$eeb09b9145034e84)(_jc_env *, struct _jc_javax_swing_JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon$object *) _JC_JCNI_ATTR;
	jboolean	(*setCurrentAccessibleValue$0ceb1cadc12f10f4)(_jc_env *, struct _jc_javax_swing_JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon$object *, struct _jc_java_lang_Number$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_accessibility_AccessibleContext$vmethods	javax_accessibility_AccessibleContext;
	_jc_java_awt_Component__24AccessibleAWTComponent$vmethods	java_awt_Component__24AccessibleAWTComponent;
	_jc_java_awt_Container__24AccessibleAWTContainer$vmethods	java_awt_Container__24AccessibleAWTContainer;
	_jc_javax_swing_JComponent__24AccessibleJComponent$vmethods	javax_swing_JComponent__24AccessibleJComponent;
	_jc_javax_swing_JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon$vmethods	javax_swing_JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon;
};

// Vtype
struct _jc_javax_swing_JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon$vtype {
	_jc_type			type;
	_jc_javax_swing_JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon$sub_refs {
	struct _jc_javax_swing_JInternalFrame__24JDesktopIcon$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon$refs {
    _jc_javax_swing_JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon$sub_refs	javax_swing_JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon;
    _jc_javax_swing_JComponent__24AccessibleJComponent$sub_refs	javax_swing_JComponent__24AccessibleJComponent;
    _jc_java_awt_Container__24AccessibleAWTContainer$sub_refs	java_awt_Container__24AccessibleAWTContainer;
    _jc_java_awt_Component__24AccessibleAWTComponent$sub_refs	java_awt_Component__24AccessibleAWTComponent;
    _jc_javax_accessibility_AccessibleContext$sub_refs	javax_accessibility_AccessibleContext;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_accessibility_AccessibleContext$sub_nonrefs	javax_accessibility_AccessibleContext;
    _jc_java_awt_Component__24AccessibleAWTComponent$sub_nonrefs	java_awt_Component__24AccessibleAWTComponent;
    _jc_java_awt_Container__24AccessibleAWTContainer$sub_nonrefs	java_awt_Container__24AccessibleAWTContainer;
    _jc_javax_swing_JComponent__24AccessibleJComponent$sub_nonrefs	javax_swing_JComponent__24AccessibleJComponent;
    _jc_javax_swing_JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon$sub_nonrefs	javax_swing_JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon;
};

// Object instance structure
struct _jc_javax_swing_JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon$object {
	_jc_javax_swing_JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon$vtype	*vtype;
	_jc_javax_swing_JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon$vtype _jc_javax_swing_JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon$class_object;

#endif	/* _JC_javax_swing_JInternalFrame__24JDesktopIcon__24AccessibleJDesktopIcon_H_ */
